| ×

| powered by |

# Audio and Video

## Recordings appear on this site by 12:00 p.m. PT the day after argument.

Windows Media Player is required to listen to audio oral arguments.

Use this page to sort and search for audio and video of Oral Arguments by case name, case number, panel, hearing location, or hearing date. If you are interested only in our videos, click here or in the Search box below, select 'Video' for 'By Type of Recording' and click 'Search'.

To sort the results, click on the header at the top of the column. To reverse the order, click the header again.

Search
by Type of Recording: |  |  |  |
by Case Name: |  |  |  |
by Case No.: |  |  |  |
by Case Panel: |  |  |  |
by Hearing Location: |  |  |  |
by Hearing Date (mm/dd/yyyy): |  |  |  |
Search type:

Results: 1 - 48 of 48 |
Pages: |<< << | 1 | >> >>|
| Page size:

loading data...

Case Name | Case No. | Case Panel | Hearing Location | Hearing Date | Audio | Video
--- | --- | --- | --- | --- | --- | ---
USA v. Joshua Hester | 13-50330 | SILVERMAN, TALLMAN, RAWLINSON | Pasadena, CA... | 07/10/2014 | Listen |
USA v. Nunzio Guadagni | 13-50282 | Benavides, WARDLAW, CLIFTON | Pasadena, CA... | 07/10/2014 | Listen |
USA v. Juan Macias | 13-50211 | Benavides, WARDLAW, CLIFTON | Pasadena, CA... | 07/10/2014 | Listen |
ASARCO v. UPRR, et al | 13-35356 | Carney, TASHIMA, MURGUIA | Seattle, WA ... | 07/10/2014 | Listen |
Michael Delegans v. Carolyn Colvin | 13-35184 | Carney, TASHIMA, MURGUIA | Seattle, WA ... | 07/10/2014 | Listen |
Amber Curtis v. Carolyn Colvin | 13-35146 | PREGERSON, PAEZ, WATFORD | Portland, OR... | 07/10/2014 | Listen |
USA v. Mark Hertler | 13-30273 | PREGERSON, PAEZ, WATFORD | Portland, OR... | 07/10/2014 | Listen |
USA v. Brian Barker | 13-30164 | PREGERSON, PAEZ, WATFORD | Portland, OR... | 07/10/2014 | Listen |
USA v. Phillip Allen | 13-30137 | Carney, TASHIMA, MURGUIA | Seattle, WA ... | 07/10/2014 | Listen |
USA v. James Postlethwaite | 13-30126 | Carney, TASHIMA, MURGUIA | Seattle, WA ... | 07/10/2014 | Listen |
Edward Zimbelman v. S Nevada Regional Housing Auth, et al | 13-17479 | Piersol, SMITH, CHRISTEN | San Francisc... | 07/10/2014 | Listen |
USA v. Carlos Martinez | 13-10390 | Piersol, SMITH, CHRISTEN | San Francisc... | 07/10/2014 | Listen |
Roberto Roman-Suaste v. Eric Holder, Jr. | 12-73905 | Benavides, WARDLAW, CLIFTON | Pasadena, CA... | 07/10/2014 | Listen |
Surjit Singh v. Eric Holder, Jr. | 12-70850 | Piersol, SMITH, CHRISTEN | San Francisc... | 07/10/2014 | Listen |
Starla Pacini, et al v. Bank of America, et al | 12-57038 | SILVERMAN, TALLMAN, RAWLINSON | Pasadena, CA... | 07/10/2014 | Listen |
Jorge Montes v. Greg Lewis | 12-55756 | SILVERMAN, TALLMAN, RAWLINSON | Pasadena, CA... | 07/10/2014 | Listen |
Sophia Daire v. Mary Lattimore | 12-55667 | Benavides, WARDLAW, CLIFTON | Pasadena, CA... | 07/10/2014 | Listen |
Gonzalo Gonzalez v. Robert Horel | 12-55661 | SILVERMAN, TALLMAN, RAWLINSON | Pasadena, CA... | 07/10/2014 | Listen |
USA v. Federal Resources Corp. | 12-36065 | Carney, TASHIMA, MURGUIA | Seattle, WA ... | 07/10/2014 | Listen |
USA v. Michael Bryant, Jr. | 12-30177 | PREGERSON, PAEZ, WATFORD | Portland, OR... | 07/10/2014 | Listen |
Zameer Azam v. Rick Hill, et al | 12-15656 | Piersol, SMITH, CHRISTEN | San Francisc... | 07/10/2014 | Listen |
Hector Aguiluz-Pineda v. Eric Holder, Jr. | 11-71415 | Benavides, WARDLAW, CLIFTON | Pasadena, CA... | 07/10/2014 | Listen |
Demian O'Keeffe v. Karla Erkenbrecher | 11-17558 | Piersol, SMITH, CHRISTEN | San Francisc... | 07/10/2014 | Listen |
Herber De Leon-Mazariegos v. Eric Holder, Jr. | 09-72496 | Piersol, SMITH, CHRISTEN | San Francisc... | 07/10/2014 | Listen |
USA v. Joshua Hester | 13-50330 | SILVERMAN, TALLMAN, RAWLINSON | Pasadena, CA... | 07/10/2014 | Listen |
USA v. Nunzio Guadagni | 13-50282 | Benavides, WARDLAW, CLIFTON | Pasadena, CA... | 07/10/2014 | Listen |
USA v. Juan Macias | 13-50211 | Benavides, WARDLAW, CLIFTON | Pasadena, CA... | 07/10/2014 | Listen |
ASARCO v. UPRR, et al | 13-35356 | Carney, TASHIMA, MURGUIA | Seattle, WA ... | 07/10/2014 | Listen |
Michael Delegans v. Carolyn Colvin | 13-35184 | Carney, TASHIMA, MURGUIA | Seattle, WA ... | 07/10/2014 | Listen |
Amber Curtis v. Carolyn Colvin | 13-35146 | PREGERSON, PAEZ, WATFORD | Portland, OR... | 07/10/2014 | Listen |
USA v. Mark Hertler | 13-30273 | PREGERSON, PAEZ, WATFORD | Portland, OR... | 07/10/2014 | Listen |
USA v. Brian Barker | 13-30164 | PREGERSON, PAEZ, WATFORD | Portland, OR... | 07/10/2014 | Listen |
USA v. Phillip Allen | 13-30137 | Carney, TASHIMA, MURGUIA | Seattle, WA ... | 07/10/2014 | Listen |
USA v. James Postlethwaite | 13-30126 | Carney, TASHIMA, MURGUIA | Seattle, WA ... | 07/10/2014 | Listen |
Edward Zimbelman v. S Nevada Regional Housing Auth, et al | 13-17479 | Piersol, SMITH, CHRISTEN | San Francisc... | 07/10/2014 | Listen |
USA v. Carlos Martinez | 13-10390 | Piersol, SMITH, CHRISTEN | San Francisc... | 07/10/2014 | Listen |
Roberto Roman-Suaste v. Eric Holder, Jr. | 12-73905 | Benavides, WARDLAW, CLIFTON | Pasadena, CA... | 07/10/2014 | Listen |
Surjit Singh v. Eric Holder, Jr. | 12-70850 | Piersol, SMITH, CHRISTEN | San Francisc... | 07/10/2014 | Listen |
Starla Pacini, et al v. Bank of America, et al | 12-57038 | SILVERMAN, TALLMAN, RAWLINSON | Pasadena, CA... | 07/10/2014 | Listen |
Jorge Montes v. Greg Lewis | 12-55756 | SILVERMAN, TALLMAN, RAWLINSON | Pasadena, CA... | 07/10/2014 | Listen |
Sophia Daire v. Mary Lattimore | 12-55667 | Benavides, WARDLAW, CLIFTON | Pasadena, CA... | 07/10/2014 | Listen |
Gonzalo Gonzalez v. Robert Horel | 12-55661 | SILVERMAN, TALLMAN, RAWLINSON | Pasadena, CA... | 07/10/2014 | Listen |
USA v. Federal Resources Corp. | 12-36065 | Carney, TASHIMA, MURGUIA | Seattle, WA ... | 07/10/2014 | Listen |
USA v. Michael Bryant, Jr. | 12-30177 | PREGERSON, PAEZ, WATFORD | Portland, OR... | 07/10/2014 | Listen |
Zameer Azam v. Rick Hill, et al | 12-15656 | Piersol, SMITH, CHRISTEN | San Francisc... | 07/10/2014 | Listen |
Hector Aguiluz-Pineda v. Eric Holder, Jr. | 11-71415 | Benavides, WARDLAW, CLIFTON | Pasadena, CA... | 07/10/2014 | Listen |
Demian O'Keeffe v. Karla Erkenbrecher | 11-17558 | Piersol, SMITH, CHRISTEN | San Francisc... | 07/10/2014 | Listen |
Herber De Leon-Mazariegos v. Eric Holder, Jr. | 09-72496 | Piersol, SMITH, CHRISTEN | San Francisc... | 07/10/2014 | Listen |

Results: 1 - 48 of 48 |
Pages: |<< << | 1 | >> >>|
| Page size:

- Electronic Filing - ECF
- Opinions
  - Published
  - Unpublished
- Calendar
  - Oral Arguments
  - Motions Panel
- Case Information
  - Dockets (PACER)
  - Pending En Banc Cases
- FAQs, Forms and
  Instructions
  - FAQs
  - After Opening a Case - Attorneys
  - After Opening a Case - Pro Se
  - Forms
  - Fee Schedule
  - Glossary
- Rules
  - FRAP & Circuit Rules
  - Streamlined Requests Replace Telephonic
    Requests for Extensions of Time
  - Electronic Submission of Excerpts
  - Proposed Rule Amendments
  - New and Amended 9th Circuit Rules
  - General Orders
- Guides and
  Legal Outlines
  - Appellate Jurisdiction in the Ninth Circuit
  - Appellate Practice Guide
  - How to File an Immigration Petition for Review
  - Ninth Circuit Immigration Outline
  - Perfecting Your Appeal
  - Section 1983 Outline
  - Social Security Outline
  - Standards of Review
- Audio and Video
- RSS Feeds

- Clerk's Office
- Mediation
- Appellate Commissioner
- Bankruptcy Appellate Panel

Welcome to the Internet portal of the United States Courts for the Ninth Circuit. more >> |  |
- Chief Judge Alex Kozinski

Site Map | Intranet (Judiciary Only) | COOP Staff Page | Seminar Disclosures | Judicial Misconduct |
Suggestions